package net.wanji.utc.service.SchemePhaseLights.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import net.wanji.utc.common.commonentity.HttpRequest;
import net.wanji.utc.common.constant.Constants;
import net.wanji.utc.common.typeenum.BasicEnum;
import net.wanji.utc.mapper.CrossSchemeMapper;
import net.wanji.utc.po.CrossSchemePO;
import net.wanji.utc.service.SchemePhaseLights.HkCrossSchemeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 方案数据-方案信息
 *
 * @author Kent HAN
 * @date 2022/11/16 15:27
 */
@Service
public class HkCrossSchemeServiceImpl implements HkCrossSchemeService {
    @Value("${signal.manufacturer.hk.artemisPath}")
    private String artemisPath;
    @Autowired
    private ArtemisConfig artemisConfig;
    @Autowired
    CrossSchemeMapper crossSchemeMapper;

    @Override
    public void hkCrossSchemeInfo(String crossCode) throws Exception {
        List<CrossSchemePO> crossSchemePOList = new ArrayList<>();

        // 请求3.1.3接口
        Map<String, String> path = getPathMapByApiCode("uploadPatternCodeList");
        Map<String, String> queryMap = new HashMap<>();
        queryMap.put("crossCode", crossCode);
        String phasePlanResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, null, queryMap,
                null, "application/json", null);
        JSONObject object = JSON.parseObject(phasePlanResult);
        if(Constants.HK_SUCCESS_CODE.equals(object.getInteger(Constants.HK_CODE_KEY))) {
            JSONArray data = object.getJSONArray("data");
            for (int i = 0; i < data.size(); i++) {
                JSONObject obj =  data.getJSONObject(i);
                String patternNo = obj.getString("patternNo");
                String patternName = obj.getString("patternName");
                // 请求3.1.4接口
                Map<String, String> path2 = getPathMapByApiCode("getCrossPlanDetail");
                Map<String, String> queryMap2 = new HashMap<>();
                queryMap2.put("crossCode", crossCode);
                queryMap2.put("patternNo", patternNo);
                String phaseDetailResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path2, null, queryMap2,
                        null, "application/json", null);
                JSONObject object2 = JSON.parseObject(phaseDetailResult);
                if(Constants.HK_SUCCESS_CODE.equals(object2.getInteger(Constants.HK_CODE_KEY))) {
                    JSONArray data2 = object2.getJSONArray("data");
                    for (int j = 0; j < data2.size(); j++) {
                        JSONObject obj2 =  data2.getJSONObject(j);
                        Integer cycle = obj2.getInteger("cycle");
                        Integer coordPhase = obj2.getInteger("coordPhase");
                        Integer offset = obj2.getInteger("offset");
                        // 构造数据库记录
                        CrossSchemePO crossSchemePO = new CrossSchemePO();
                        crossSchemePO.setNo(patternNo);
                        crossSchemePO.setName(patternName);
                        crossSchemePO.setCrossId(crossCode);
                        crossSchemePO.setCycle(cycle);
                        crossSchemePO.setCoordPhase(coordPhase);
                        crossSchemePO.setOffset(offset);
                        crossSchemePO.setSource(2);
                        crossSchemePO.setIsDeleted(0);

                        crossSchemePOList.add(crossSchemePO);
                    }
                }
            }
        }
        // 写入数据库
        crossSchemeMapper.insertBatch(crossSchemePOList);
    }

    private Map<String, String> getPathMapByApiCode(String apiCode) {
        Map<String, String> res = new HashMap<>();
        HttpRequest httpRequest = new HttpRequest(BasicEnum.ManufacturerEnum.HK.getAbbr(), apiCode);
        res.put("http://", artemisPath + httpRequest.getUrl());
        return res;
    }
}
